@@ -73,8 +73,12 @@ public:
     /* undo last action (if it exists) and return the changed coordinate. */
     QPoint undo();
 
+    /* Uncovers a single, random, still uncovered cell. */
     QPoint hint();
 
+    /* Solves the entire board, but does not emit the gameWon signal. */
+    void solve();
+
     /* if a saved state exists, load it. otherwise, do nothing */
     void loadState() { m_state->loadState(); m_streaks->update(); emit stateChanged(); }
     void saveState() { m_state->saveState(); }
@@ -87,6 +91,10 @@ public:
     QVector<QSharedPointer<Streaks::StreakElement> > getColStreak(int x) const;
 
 signals:
+    /** Emitted when the game has been completed in any way. Also triggered if "Solve" was used. */
+    void gameCompleted();
+
+    /** Emitted when the game has actually been won (i.e. "Solve" wasn't used). */
     void gameWon();
 
     /**
